import React from 'react';
import { Config, PluginDefinition, TinyCarousel as TinyCarouselCore } from '@frsource/tiny-carousel-core';
import type { CustomEventListener, EventDetailMap } from '@frsource/tiny-carousel-utils';
import type { OmitFirstItem } from '@frsource/tiny-carousel-core/dist/helpers';
export declare type PluginProp<PD extends PluginDefinition> = [PD, ...OmitFirstItem<Parameters<PD['install']>>];
export declare type PluginsProp<PD extends PluginDefinition = PluginDefinition<undefined | unknown[]>> = PluginProp<PD>[];
export declare type PluginDefinitionConfig<PD extends PluginDefinition> = PD extends PluginDefinition<infer C> ? C : never;
export declare const definePlugin: <PD extends {
    install(instance: TinyCarouselCore): void;
} | {
    install(instance: TinyCarouselCore, ...args: unknown[]): void;
}, C extends PluginDefinitionConfig<PD>>(...args: C extends unknown[] ? [PD, ...C] : [PD]) => C extends unknown[] ? [PD, ...C] : [PD];
declare type KebabToCamelCase<Set extends string> = Set extends `${infer P}-${infer S}` ? `${P}${Capitalize<KebabToCamelCase<S>>}` : Set;
declare type RenamePrefix<Set extends string> = Set extends `${infer P}:${infer S}` ? `on${Capitalize<P>}Event${Capitalize<S>}` : `onEvent${Capitalize<Set>}`;
declare type TinyCarouselReactEventProps<K extends keyof EventDetailMap = keyof EventDetailMap> = 
/** Makes fields optional */
Partial<Record<RenamePrefix<KebabToCamelCase<K>>, CustomEventListener<K>>>;
export interface TinyCarouselProps extends TinyCarouselReactEventProps {
    /** [string] - let's you render a custom tag element as TinyCarousel wrapper (default: "ul") */
    tag?: keyof JSX.IntrinsicElements;
    /** [string] - adds classname on main carousel wrapper  */
    className?: string;
    /** [PluginsProp] - import plugins from TinyCarousel ecosystem to this carousel instance */
    plugins?: PluginsProp;
    /** [Partial<Config>] - configure this TinyCarousel instance */
    config?: Partial<Config>;
    /** [React.ReactNode] - pass in the carousel slides */
    children?: React.ReactNode;
}
export declare type TinyCarouselRef = TinyCarouselCore | undefined;
declare const TinyCarousel: React.ForwardRefExoticComponent<TinyCarouselProps & React.RefAttributes<TinyCarouselRef>>;
export default TinyCarousel;
